import { AxiosInstance } from "axios";
import { InstTyp } from "./dto/InstTyp";
import { BalanceDto } from "./dto/balance.dto";
import { ConfigDto } from "./dto/config.dto";
import { ClosePositionsInputDto, ClosePositionsResponseDto, PositionDto } from "./dto/position.dto";
import { LeverageReponseDto, LeverageInputDto } from "./dto/leverage.dto";
import { OrderInpoutDto, OrderResponseDto, OrderDetails, OrderListInput, AlgoOrderInpoutDto, AlgoOrderResponseDto, AlgoStopTpInputDto, AlgoTrailStopInputDto, AlgoTrigetInputDto, AlgoIcebergInputDto, AlgoTWAPInputDto, CancelAlgoOrderInputDto, AlgoOrderListInput, AlgoOrderDetails, AlgoOrderHistoryInput, AlgoOrderHistoryResponse, OrderHistoryInput, OrderHistoryResponse } from "./dto/order.dto";
import { CancelOrderInputDto, CancelOrderResponseDto } from "./dto/cancel-order.dto";
import { CurrencyDto } from "./dto/currency.dto";
import { InstrumentDto } from "./dto/instrument.dto";
declare class HttpApi {
    apiClient: AxiosInstance;
    signer: any;
    apiKey: string;
    passphrase: string;
    apiSecret: string;
    constructor(apiKey: string, apiSecret: string, passphrase: string, baseURL?: string);
    getSignedHeader(method: string, path: string, params?: any): {
        "OK-ACCESS-KEY": string;
        "OK-ACCESS-TIMESTAMP": string;
        "OK-ACCESS-SIGN": string;
        "OK-ACCESS-PASSPHRASE": string;
    };
    get<T>(path: string, params?: any): Promise<T>;
    post<T>(path: string, body: any): Promise<T>;
    getTickers(instType: InstTyp): Promise<any>;
    getAccountConfig(): Promise<ConfigDto>;
    getBalance(coins?: string): Promise<BalanceDto>;
    getPositions(instType?: InstTyp | string, instId?: string, posId?: string): Promise<PositionDto[]>;
    setLeverage(input: LeverageInputDto): Promise<LeverageReponseDto>;
    placeOrder(input: OrderInpoutDto): Promise<OrderResponseDto>;
    placeMultipleOrders(input: OrderInpoutDto[]): Promise<OrderResponseDto[]>;
    cancelOrder(input: CancelOrderInputDto): Promise<CancelOrderResponseDto>;
    cancelMultipleOrders(input: CancelOrderInputDto[]): Promise<CancelOrderResponseDto[]>;
    getOrderDetails(instId: string, ordId?: string, clOrdId?: string): Promise<OrderDetails>;
    getOrderList(input?: OrderListInput | undefined): Promise<OrderDetails[]>;
    getOrderHistory7DaysBefore(input: OrderHistoryInput): Promise<OrderHistoryResponse[]>;
    getAlgoOrderList(input?: AlgoOrderListInput | undefined): Promise<AlgoOrderDetails[]>;
    getAlgoOrderHistory(input?: AlgoOrderHistoryInput | undefined): Promise<AlgoOrderHistoryResponse[]>;
    closePositions(input: ClosePositionsInputDto): Promise<ClosePositionsResponseDto[]>;
    placeAlgoOrder(input: AlgoOrderInpoutDto, input2: AlgoStopTpInputDto | AlgoTrailStopInputDto | AlgoTrigetInputDto | AlgoIcebergInputDto | AlgoTWAPInputDto): Promise<AlgoOrderResponseDto>;
    cancelAlgoOrders(input: CancelAlgoOrderInputDto[]): Promise<AlgoOrderResponseDto>;
    getCurrencies(ccy?: string): Promise<CurrencyDto[]>;
    getInstruments(instType: "SPOT" | "MARGIN" | "SWAP" | "FUTURES" | "OPTION", uly?: string, instId?: string): Promise<InstrumentDto[]>;
}
export default HttpApi;
